"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils = require("../utils");
const Dockerode = require('dockerode');
/**
 * Describes a way to build a microservice.
 */
class Build {
    /**
     * Build a {@link Build}.
     *
     * @param {String} name The given name
     */
    constructor(name) {
        this.name = name;
    }
    /**
     * Builds a Docker image with this {@link Build}'s name prefaced with `omg/` and tagged with `local`.
     *
     * @param {Boolean} [silent=false] The given boolean if output should be logged or not
     * @param  {boolean} [ui=false] The given boolean if ui mode is enabled or not
     * @return {String} The name of the docker container that was build
     */
    go(silent = false, ui = false) {
        return __awaiter(this, void 0, void 0, function* () {
            if (ui) {
                const stream = yield utils.docker.buildImage({
                    context: process.cwd()
                }, { t: this.name });
                return stream;
            }
            else {
                const stream = yield utils.docker.buildImage({
                    context: process.cwd()
                }, { t: this.name });
                const dockerode = new Dockerode();
                const log = yield new Promise((resolve, reject) => {
                    dockerode.modem.followProgress(stream, (err, res) => err ? reject(err) : resolve(res));
                });
                if (!silent) {
                    for (const line in log) {
                        if (log[line].stream && log[line].stream.length > 1) {
                            utils.log(log[line].stream.trim());
                        }
                    }
                }
                return this.name;
            }
        });
    }
}
exports.default = Build;
//# sourceMappingURL=Build.js.map