"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const Run_1 = require("./Run");
const homedir = require('os').homedir();
/**
 * Represents a execution of an {@link Action}'s {@link Event}.
 */
class EventRun extends Run_1.default {
    /**
     * Builds an {@link EventRun}.
     *
     * @param {String} dockerImage The given docker image
     * @param {Microservice} microservice The given {@link Microservice}
     * @param {Object} _arguments The given argument map
     * @param {Object} environmentVariables The given environment map
     */
    constructor(dockerImage, microservice, _arguments, environmentVariables) {
        super(dockerImage, microservice, _arguments, environmentVariables);
    }
    /** @inheritdoc */
    exec(action) {
        return __awaiter(this, void 0, void 0, function* () {
            this.action = this.microservice.getAction(action);
            this.preChecks();
            this.verification();
            this.omgJsonFileHandler();
            return '';
        });
    }
    /**
     * Handle the `.omg.json` state file.
     */
    omgJsonFileHandler() {
        let data = {};
        if (fs.existsSync(`${homedir}/.omg.json`)) {
            data = JSON.parse(fs.readFileSync(`${homedir}/.omg.json`).toString());
        }
        data[process.cwd()] = {
            container_id: this.containerID,
            ports: {}
        };
        const neededPorts = Object.keys(this.portMap);
        for (let i = 0; i < neededPorts.length; i += 1) {
            data[process.cwd()].ports[neededPorts[i]] = this.portMap[neededPorts[i]];
        }
        fs.writeFileSync(`${homedir}/.omg.json`, JSON.stringify(data), 'utf8');
    }
    /** @inheritdoc */
    isDockerProcessRunning() {
        return this.containerID !== null;
    }
    /**
     * @param  {any} args
     */
    setArgs(args) { }
}
exports.default = EventRun;
//# sourceMappingURL=EventRun.js.map