"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const FormatRun_1 = require("./FormatRun");
const HttpRun_1 = require("./HttpRun");
const EventRun_1 = require("./EventRun");
const UIRun_1 = require("./UIRun");
/**
 * Represents a factory to build an {@link Run}.
 */
class RunFactory {
    /**
     * Build an {@link RunFactory}.
     *
     * @param {String} dockerImage The given docker image
     * @param {Microservice} microservice The given {@link Microservice}
     * @param {Object} _arguments The given argument map
     * @param {Object} environmentVariables the given environment  map
     */
    constructor(dockerImage, microservice, _arguments, environmentVariables) {
        this.dockerImage = dockerImage;
        this.microservice = microservice;
        this._arguments = _arguments;
        this.environmentVariables = environmentVariables;
    }
    /**
     * Builds a {@link FormatRun}, {@link HttpRun}, or {@link EventRun} based on the given {@link Action}.
     *
     * @param {Action} action The given {@link Action}
     * @param {ui} [ui=false] The given boolean wich defines if running in ui mode or not
     * @return {Run} The {@link FormatRun}, {@link HttpRun}, or {@link EventRun}
     */
    getRun(action, ui = false) {
        if (ui === true) {
            return new UIRun_1.default(this.dockerImage, this.microservice, this.environmentVariables);
        }
        else if (action.format !== null) {
            return new FormatRun_1.default(this.dockerImage, this.microservice, this._arguments, this.environmentVariables);
        }
        else if (action.http !== null) {
            return new HttpRun_1.default(this.dockerImage, this.microservice, this._arguments, this.environmentVariables);
        }
        else if (action.events !== null) {
            return new EventRun_1.default(this.dockerImage, this.microservice, this._arguments, this.environmentVariables);
        }
    }
}
exports.default = RunFactory;
//# sourceMappingURL=RunFactory.js.map